@@ -1,7 +1,3 @@
-#' @importFrom graphics plot
-#' @importFrom stats aggregate
-#' @importFrom utils download.file read.csv unzip read.table tail
-
 #' @title Full Path
 #' @description Return normalized path for all operating systems
 #' @param reference_path a path to join with current working directory
@@ -25,8 +21,9 @@ full_path <- function(reference_path, base_path = getwd()) {
 #' @description This downloads the latest portal data regardless if they are
 #'   actually updated or not.
 #'   TODO: incorporate data retriever into this when it's pointed at the github repo
-#' @param base_folder Folder into which data will be downloaded
+#' @param path Folder into which data will be downloaded
 #' @param version Version of the data to download (default = "latest")
+#' @param quiet logical, whether to download data silently
 #' @inheritParams get_data_versions
 #'
 #' @return None
@@ -38,7 +35,9 @@ full_path <- function(reference_path, base_path = getwd()) {
 #' }
 #'
 #' @export
-download_observations <- function(base_folder = "~", version = "latest", from_zenodo = FALSE)
+download_observations <- function(path = get_default_data_path(),
+                                  version = "latest", from_zenodo = FALSE,
+                                  quiet = FALSE)
 {
   # only use zenodo if version == "latest"
   if (version != "latest")
@@ -70,12 +69,13 @@ download_observations <- function(base_folder = "~", version = "latest", from_ze
   }
 
   # Attemt to download the zip file
-  message("Downloading version ", releases$version[match_idx], " of the data...")
+  if (!quiet)
+    message("Downloading version ", releases$version[match_idx], " of the data...")
   zip_download_path <- releases$zipball_url[match_idx]
   zip_download_dest <- full_path("PortalData.zip", tempdir())
   download.file(zip_download_path, zip_download_dest, quiet = TRUE, mode = "wb")
 
-  final_data_folder <- full_path("PortalData", base_folder)
+  final_data_folder <- full_path("PortalData", path)
 
   # Clear out the old files in the data folder without doing potentially dangerous
   # recursive deleting.
@@ -93,10 +93,10 @@ download_observations <- function(base_folder = "~", version = "latest", from_ze
 
   #Github serves this up with the -master extension. Unzip and rename to remove that.
   primary_data_folder <- unzip(zip_download_dest, list = TRUE)$Name[1]
-  unzip(zip_download_dest, exdir = base_folder)
+  unzip(zip_download_dest, exdir = path)
   Sys.sleep(10)
   file.remove(zip_download_dest)
-  file.rename(full_path(primary_data_folder, base_folder), final_data_folder)
+  file.rename(full_path(primary_data_folder, path), final_data_folder)
 }
 
 #' @title get version and download info for PortalData
@@ -113,7 +113,7 @@ download_observations <- function(base_folder = "~", version = "latest", from_ze
 #' @export
 get_data_versions <- function(from_zenodo = FALSE, halt_on_error = FALSE)
 {
-  releases   <- tryCatch(
+  releases <- tryCatch(
     {
       if (from_zenodo)
       {
@@ -243,19 +243,21 @@ get_github_releases <- function()
 #' @title Check for latest version of data files
 #' @description Check the latest version against the data that exists on
 #'   the GitHub repo
-#' @param base_folder Folder in which data will be checked
+#' @param path Folder in which data will be checked
+#' @param mustWork logical: if TRUE then an error is given if the result cannot
+#'   be determined; if NA then a warning.
 #'
 #' @return bool TRUE if there is a newer version of the data online
 #'
 #' @export
-check_for_newer_data <- function(base_folder = "~")
+check_for_newer_data <- function(path = get_default_data_path(), mustWork = TRUE)
 {
   # first see if the folder for the data files exist
-  tryCatch(base_path <- file.path(normalizePath(base_folder, mustWork = TRUE), "PortalData"),
-           error = function(e) stop("Unable to use the specified path: ", base_folder, call. = FALSE),
-           warning = function(w) w)
+  tryCatch(base_path <- file.path(normalizePath(path, mustWork = mustWork), "PortalData"),
+           error = function(e) stop("Unable to use the specified path: ", path, call. = FALSE),
+           warning = function(w) {warning(w); return(NA)})
 
-  # check for `version.txt``
+  # check for `version.txt`
   version_file <- file.path(base_path, "version.txt")
   if (!file.exists(version_file)) # old version of data is missing this metadata file
     return(TRUE)
@@ -291,3 +293,93 @@ check_for_newer_data <- function(base_folder = "~")
 
   return(FALSE)
 }
+
+#' @rdname use_default_data_path
+#'
+#' @description \code{check_default_data_path} checks if a default data path is
+#'   set, and prompts the user to set it if it is missing.
+#'
+#' @inheritParams use_default_data_path
+#' @param MESSAGE_FUN the function to use to output messages
+#' @param DATA_NAME the name of the dataset to use in output messages
+#' @return FALSE if there is no path set, TRUE otherwise
+#'
+#' @export
+#'
+check_default_data_path <- function(ENV_VAR = "PORTALR_DATA_PATH",
+                                    MESSAGE_FUN = message, DATA_NAME = "Portal data")
+{
+  if (is.na(get_default_data_path(fallback = NA, ENV_VAR)))
+  {
+    MESSAGE_FUN("You don't appear to have a defined location for storing ", DATA_NAME, ".")
+    code_call_str <- (crayon::make_style("darkgrey"))(encodeString('use_default_data_path(\"<path>\")', quote = "`"))
+    MESSAGE_FUN(crayon::red(clisymbols::symbol$bullet),
+                " Call ", code_call_str, " if you wish to set the default data path.")
+    default_path_str <- (crayon::make_style("darkgrey"))(encodeString(path.expand("~"), quote = "`"))
+    MESSAGE_FUN(DATA_NAME, " will be downloaded into ", default_path_str, " otherwise.")
+    return(FALSE)
+  }
+  return(TRUE)
+}
+
+#' @rdname use_default_data_path
+#'
+#' @description \code{get_default_data_path} gets the value of the data path
+#'   environmental variable
+#'
+#' @inheritParams use_default_data_path
+#' @param fallback the default value to use if the setting is missing
+#'
+#' @export
+#'
+get_default_data_path <- function(fallback = "~", ENV_VAR = "PORTALR_DATA_PATH")
+{
+  Sys.getenv(ENV_VAR, unset = fallback)
+}
+
+#' @name use_default_data_path
+#' @aliases get_default_data_path
+#'
+#' @title Manage the default path for downloading Portal Data into
+#'
+#' @description \code{use_default_data_path} has 3 steps. First, it checks for
+#'   the presence of a pre-existing setting for the environmental variable.
+#'   Then it checks if the folder exists and creates it, if needed. Then it
+#'   provides instructions for setting the environmental variable.
+#' @inheritParams download_observations
+#' @param ENV_VAR the environmental variable to check (by default
+#'   `"PORTALR_DATA_PATH"``)
+#'
+#' @return None
+#'
+#' @export
+use_default_data_path <- function(path = NULL, ENV_VAR = "PORTALR_DATA_PATH")
+{
+  # check for prexisting setting
+  curr_data_path <- Sys.getenv(ENV_VAR, unset = NA)
+  if (!is.na(curr_data_path))
+  {
+    warning("A default data path exists:", Sys.getenv(ENV_VAR), ".")
+  }
+
+  # check if a path is provided
+  if (is.null(path))
+  {
+    usethis::ui_stop("Please provide a path to store downloaded data.")
+  }
+
+  # check if path is valid
+  if (!dir.exists(path))
+  {
+    dir.create(path)
+  }
+
+  # copy new path setting to clipboard
+  path_setting_string <- paste0(ENV_VAR, "=", '"', path, '"')
+
+  usethis::ui_todo("Call {usethis::ui_code('usethis::edit_r_environ()')} to open {usethis::ui_path('.Renviron')}")
+  usethis::ui_todo("Store your data path with a line like:")
+  usethis::ui_code_block(path_setting_string)
+  usethis::ui_todo("Make sure {usethis::ui_value('.Renviron')} ends with a newline!")
+  return()
+}
